@@ -19,11 +19,11 @@ Audit::DBI - Audit data changes in your code and store searchable log records in
 
 =head1 VERSION
 
-Version 1.4.2
+Version 1.4.3
 
 =cut
 
-our $VERSION = '1.4.2';
+our $VERSION = '1.4.3';
 
 
 =head1 SYNOPSIS
@@ -915,11 +915,15 @@ sub insert_event
 			croak 'The "diff" argument cannot have more than two elements'
 				if scalar( @{ $data->{'diff'} } ) > 2;
 			
-			$data->{'diff'} = MIME::Base64::encode_base64(
-				Storable::freeze(
-					Audit::DBI::Utils::diff_structures( @{ $data->{'diff'} } )
+			my $diff = Audit::DBI::Utils::diff_structures( @{ $data->{'diff'} } );
+			
+			$data->{'diff'} = defined( $diff )
+				? MIME::Base64::encode_base64(
+					Storable::freeze(
+						$diff
+					)
 				)
-			);
+				: undef;
 		}
 		
 		# Clean input.
